\name{luvtoMunsell}
\alias{luvtoMunsell}
\title{Convert CIE Luv coordinates into a Munsell specification}
\description{\code{luvtoMunsell} Converts CIE Luv coordinates into a Munsell 
specification, by interpolating over the extrapolated Munsell renotation data
}

\usage{luvtoMunsell( Luv, white=c(95.047,100,108.883), adaption='bradford', ... ) }
\arguments{
  \item{Luv}{CIE Luv coordinates An Nx3 matrix, or a vector that can be converted to such a matrix. Each row of the matrix has Luv.}
  \item{white}{XYZ for the reference white.  The default is Illuminant=D65, 2 observer}
  \item{adaption}{method for chromatic adaption, see \bold{Details}}
  \item{...}{other parameters passed to \code{\link{XYZtoMunsell}()} }  
}

\value{
An Nx3 matrix with the Munsell HVC coordinates in each row.
The rownames are set to those of Luv.
}

\details{
The conversion is done in 3 steps.
\itemize{
\item Luv \rarrow XYZ using \code{\link{luv2xyz}()} with the given \code{white}.
\item XYZ is then adapted from the given \code{white} to Illuminant C using
the given \code{adaption} method, see \link{adaption}.
\item XYZ \rarrow HVC using \code{\link{XYZtoMunsell}()}
}
}


\references{
Paul Centore 2014
The Munsell and Kubelka-Munk Toolbox
\url{http://www.99main.com/~centore/MunsellAndKubelkaMunkToolbox/MunsellAndKubelkaMunkToolbox.html}
}

\author{Jose Gama and Glenn Davis}
\examples{
luvtoMunsell( c( 74.613450, -5.3108, 10.6 ) )
}
\keyword{datasets}

